from setuptools import setup

setup(name='pete_game_test1',
      version='0.2',
      description='test pete game upload',
      packages=['pete_game_test'],
      author='Pete Tae',
      email='pete.taecha@gmail.com',
      zip_safe=False)
